package com.menutoday.controller;

import java.security.Principal;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.log4j.Logger;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.multipart.MaxUploadSizeExceededException;
import org.springframework.web.servlet.HandlerExceptionResolver;
import org.springframework.web.servlet.ModelAndView;

import com.menutoday.service.MenuTodayService;
import com.menutoday.utils.PerfilType;

/**
 * 
 * @author igomezuoc
 *
 */
@Controller
@RequestMapping("/*")
public class MainController implements HandlerExceptionResolver {

	private Logger log = Logger.getLogger(this.getClass());

	@Resource(name = "mockMenuTodayService")
	private MenuTodayService menuTodayService;
	
	public MainController() {
		super();
	}
	
	// Common Views
	@RequestMapping("/master")
	public ModelAndView init(HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) 
			throws Exception{
		ModelAndView result;
		this.log.debug("user Name --> " + principal.getName());
		PerfilType perfil = this.menuTodayService.getPerfil (principal.getName());
		if (PerfilType.isRoleRestaurant(perfil)) {
			result = new ModelAndView("menutoday/restaurants/resta-llista");
		} else if (PerfilType.isRoleUser(perfil) || (PerfilType.isRoleAdmin(perfil))) {
			result = new ModelAndView("menutoday/users/users-menu-inici");
		} else {
			throw new Exception ("Perfil not found: " + perfil);
		}
		return result;
	}
	

	@RequestMapping("/solicituds/alta")
	public ModelAndView solicitudAlta (HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/solicituds/solicituds-enviades");
	}

	@RequestMapping("/solicituds/rebre")
	public ModelAndView solicitudRebuda (HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/solicituds/solicituds-rebudes");
	}
	
	// Users Views
	@RequestMapping("/users/meus-restaurants")
	public ModelAndView meusRestaurants(HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/users/users-meus-restaurants");
	}

	@RequestMapping("/users/reserves")
	public ModelAndView usersReserves (HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/users/users-reserves");
	}
	
	@RequestMapping("/users/reserva-confirmada")
	public ModelAndView usersReservaConfirmada (HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/users/users-reserva-confirmada");
	}
	
	@RequestMapping("/users/promocions")
	public ModelAndView promocions (HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/users/users-promocions");
	}

	// Restaurants Views
	@RequestMapping("/restaurant/llistat")
	public ModelAndView veureRestaurants (HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/restaurant/resta-llista");
	}

	@RequestMapping("/restaurant/selecciona")
	public ModelAndView seleccionaRestaurant (HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/restaurant/resta-selecciona");
	}

	@RequestMapping("/restaurant/menu")
	public ModelAndView veureMenu (HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/restaurant/resta-menu");
	}
	
	@RequestMapping("/restaurant/reserves")
	public ModelAndView restaurantReserves (HttpSession session, HttpServletRequest request, HttpServletResponse response, Principal principal) {
		return new ModelAndView("menutoday/restaurant/resta-reserves");
	}
	
	@Override
	public ModelAndView resolveException(HttpServletRequest request, HttpServletResponse response, Object handler,
			Exception ex) {
		HttpSession session = request.getSession();
		if (ex instanceof MaxUploadSizeExceededException) {
			ControllerUtils.setError("File size exceeds the configured maximum..", session);
		} else {
			// We only put in the controller message controlled exceptions. If there is any other exception, we send a
			// generic error to the user
			this.log.error("Exception received in MainController", ex);
			ControllerUtils.setError("Unexpected internal error", session);
		}
		return this.pageError(session, request, response);
	}
	
	@RequestMapping("/pageError")
	public ModelAndView pageError(HttpSession session, HttpServletRequest request, HttpServletResponse response) {
		ModelAndView result = new ModelAndView("menutoday/pageError");
		return result;
	}

}
