package com.menutoday.controller;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;

import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.menutoday.dao.bo.Menu;
import com.menutoday.dao.bo.Restaurant;
import com.menutoday.service.MenuTodayService;
import com.menutoday.utils.DataSliderUtil;



/**
 * 
 * @author igomezuoc
 *
 */
@Controller
@RequestMapping("/*")
public class RestController {

//	@Resource ServletContext servletContext;
//	@Resource HttpServletRequest servletRequest;
	
	@Resource (name = "mockMenuTodayService")
	MenuTodayService menuTodayService;
	
	public RestController() {
		super();
	}
	
	@RequestMapping(value="/users/rest/restaurants/slides/{id}/{day}", method=RequestMethod.GET)
	@ResponseBody
	@ResponseStatus(value=HttpStatus.OK)
	public List<String> getSlidesByUser(@PathVariable String id, @PathVariable String day) throws Exception {
		List<String> result = new ArrayList<String>();
		List<Menu> menus = menuTodayService.getMenusByUser (id, day);
		String response = DataSliderUtil.wrapToJQueryObject(menus);
		result.add(response);
		return result;
	}
	
	@RequestMapping(value="/users/rest/restaurants/{user}/{sorted}", method=RequestMethod.GET)
	@ResponseBody
	@ResponseStatus(value=HttpStatus.OK)
	public List<Restaurant> getRestaurantsByUser(@PathVariable String user, @PathVariable String sorted) throws Exception {
		return menuTodayService.getRestaurantsByUser(user, sorted);
	}
	
	@RequestMapping(value="/users/rest/getRestaurant/{id}", method=RequestMethod.GET)
	@ResponseBody
	@ResponseStatus(value=HttpStatus.OK)
	public List<Restaurant> getRestaurantsById(@PathVariable int id) throws Exception {
		List<Restaurant> result = new ArrayList<Restaurant>();
		Restaurant tmp = menuTodayService.getRestaurantsById(id);
		if (tmp != null) {
			result.add (tmp);
		}
		return result;
	}
	
	@RequestMapping(value="/users/rest/getMenu/{id}/{day}", method=RequestMethod.GET)
	@ResponseBody
	@ResponseStatus(value=HttpStatus.OK)
	public List<Menu> getMenu(@PathVariable int id, @PathVariable String day) throws Exception {
		return  menuTodayService.getMenusById(id, day);
	}
	

	
	@RequestMapping(value="/users/rest/addReserva/{user}/{day}/{restaurant}", method=RequestMethod.PUT)
	@ResponseBody
	@ResponseStatus(value=HttpStatus.CREATED)
	public List<String> addReserva(@PathVariable String user, @PathVariable String day, @PathVariable int restaurant) throws Exception {
		List<String> result = new ArrayList<String>();
		if (menuTodayService.isReservaInDay (user, day) == null) {
			menuTodayService.addReserva (user, day, restaurant);
			result.add("OK");
		} else {
			result.add("KO");
		}
		return result;
	}
	
	@RequestMapping(value="/users/rest/removeReserva/{user}/{day}", method=RequestMethod.DELETE)
	@ResponseBody
	@ResponseStatus(value=HttpStatus.NO_CONTENT)
	public List<String> removeReserva(@PathVariable String user, @PathVariable String day) throws Exception {
		List<String> result = new ArrayList<String>();
		if (menuTodayService.isReservaInDay (user, day) != null) {
			menuTodayService.removeReserva (user, day);
			result.add("OK");
		} else {
			result.add("KO");
		}
		return result;
	}
	
	@RequestMapping(value="/users/rest/getReserva/{user}/{day}", method=RequestMethod.GET)
	@ResponseBody
	@ResponseStatus(value=HttpStatus.OK)
	public List<Restaurant> getReserva(@PathVariable String user, @PathVariable String day) throws Exception {
		Restaurant response = menuTodayService.isReservaInDay(user, day);
		List<Restaurant> result = new ArrayList<Restaurant>();
		if (response != null) {
			result.add(response);
		}
		return result;
	}
	
	@RequestMapping(value="/users/rest/getSolicituds/{user}/{status}", method=RequestMethod.GET)
	@ResponseBody
	@ResponseStatus(value=HttpStatus.OK)
	public List<Restaurant> getSolicituds(@PathVariable String user, @PathVariable String status) throws Exception {
		return menuTodayService.getSolicituds (user, status);
	}
	
	@RequestMapping(value="/users/rest/approveSolicituds/{user}/{ids}", method=RequestMethod.PUT)
	@ResponseBody
	@ResponseStatus(value=HttpStatus.CREATED)
	public List<String> approveSolicitud(@PathVariable String user, @PathVariable String ids) throws Exception {
		List<String> result = new ArrayList<String>();
		this.menuTodayService.approveSolicituds (user, ids);
		result.add("OK");
		return result;
	}
	
	
//	private String getUrlBase () {
//		return "http://" + servletRequest.getServerName() + ":" + servletRequest.getServerPort() + servletRequest.getContextPath() ;		
//	}
}
