package com.menutoday.dao.bo;

import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import org.springframework.stereotype.Repository;

import com.menutoday.dao.bo.pk.MenuPK;
import com.menutoday.dao.bo.pk.ReservaPK;
import com.menutoday.utils.DateUtils;

/**
 * 
 * @author igomezuoc
 *
 */
@Repository("mockMenuAppData")
public class MockMenuAppData {

	//maps
	private Map<String, List<Restaurant>> mapRestaurants;
	
	private Map<String, List<Restaurant>> mapEmpreses;

	private Map<MenuPK, List<Menu>> mapMenus;
	
	private Map<ReservaPK, Restaurant> mapReserves;
	
	private Map<String, List<Restaurant>> mapSolicitudsPendents;
	
	//listas
	private List<Restaurant> listRestaurants;
	
	private List<Menu> listMenu;

	public static final String BASE_URL = "/menuapp";
	
	public MockMenuAppData () {
		
		try {
			initRestaurants ();
			
			initMenus ();
			
			initMapMenusRestaurants ();
			
			initMapUsersRestaurants ();
			
			initMapUsersEmpreses ();
			
			initMapUsersReserves ();
			
			initMapSolicitudsEmpreses ();
			
		} catch (IOException e) {
			e.printStackTrace();
		} catch (URISyntaxException e) {
			e.printStackTrace();
		}
	}

	/**
	 * 
	 */
	private void initMapSolicitudsEmpreses() {
		mapSolicitudsPendents = new HashMap<String, List<Restaurant>>();
		List<Restaurant> value = new LinkedList<Restaurant>();
		value.add(listRestaurants.get(3));
		value.add(listRestaurants.get(4));
		value.add(listRestaurants.get(5));
		mapSolicitudsPendents.put("company A", value);
	}


	/**
	 * Inicializa menus
	 * @throws URISyntaxException
	 */
	private void initMenus () throws URISyntaxException {
		listMenu = new LinkedList<Menu>();
		
		Plats plat1 = new Plats(new String [] {"Crema de esprrags","Amanida verde","Salm Ahumat amb esprracs"}, 
								new String [] {"Merlua al forn","Entrecot de vedella","Costilletes de porc"}, 
								new String [] {"Fruita de temporada","Crema catalana","Tarta de llimona"}, 
								new String [] {"P i beguda inclosa"});
		
		listMenu.add(new Menu(1, new URI(BASE_URL+"/menutoday/users/reserves/?rest=1"), new URI(BASE_URL+"/img/menus/msample1.jpg"), plat1));
		
		Plats plat2 = new Plats(new String [] {"Pinxos al plat","Sopa de llenties","Amanida pollastre i pinya"}, 
				new String [] {"Xuletes de porc","Pit de pollastre a la planxa","Paella valenciana"}, 
				new String [] {"Natilles caseres","Flan de la casa","Gelat de xocolata/vainilla"}, 
				new String [] {"P i beguda no inclosa"});
		
		listMenu.add(new Menu(2, new URI(BASE_URL+"/menutoday/users/reserves/?rest=2"), new URI(BASE_URL+"/img/menus/msample2.jpg"), plat2));
		
		
		Plats plat3 = new Plats(new String [] {"Primer Plat 11","Primer Plat 22","Primer Plat 33"}, 
				new String [] {"Segon Plat 11","Segon Plat 22","Segon Plat 33"}, 
				new String [] {"Postre 11","Postre 32","Postre 33"}, 
				new String [] {"P i beguda inclosa"});
		
		listMenu.add(new Menu(3, new URI(BASE_URL+"/menutoday/users/reserves/?rest=3"), new URI(BASE_URL+"/img/menus/msample3.jpg"), plat3));
		
		
		Plats plat4 = new Plats(new String [] {"Albondigues","Gaspatxo","Amanida catalana"}, 
				new String [] {"Risoto vegetal","Pasta amb bolets","Hamburguesa casera"}, 
				new String [] {"Yogurt natural","Crema de platans amb xocolata","Tarta de formatge i fresa"}, 
				new String [] {"P i beguda inclosa"});
		
		listMenu.add(new Menu(4, new URI(BASE_URL+"/menutoday/users/reserves/?rest=4"), new URI(BASE_URL+"/img/menus/msample4.jpg"), plat4));	
		
		
		Plats plat5 = new Plats(new String [] {"Amanida rusa","Sopa vegetal","Llenties de la casa"}, 
				new String [] {"Xorio amb patates","Salm a la planxa","Careta de porc"}, 
				new String [] {"Gelats variats","Tarta de xocolata","Mousse de vainilla"}, 
				new String [] {"P i beguda no inclosa"});
		
		listMenu.add(new Menu(5, new URI(BASE_URL+"/menutoday/users/reserves/?rest=5"), new URI(BASE_URL+"/img/menus/msample5.jpg"), plat5));	
		
		
		Plats plat6 = new Plats(new String [] {"Amanida de pasta i tonyina","Arrs xins","Flaut de pernil ibric"}, 
				new String [] {"Broxeta casolana","Carcols a la caola","Estofat de ternera i patates hervides"}, 
				new String [] {"Tiramis","Tarta de poma","Empanada de fresa"}, 
				new String [] {"P i beguda inclosa"});
		
		listMenu.add(new Menu(6, new URI(BASE_URL+"/menutoday/users/reserves/?rest=6"), new URI(BASE_URL+"/img/menus/msample6.jpg"), plat6));	
		
	}

	/**
	 * Inicializa restaurantes
	 * @throws IOException
	 * @throws URISyntaxException 
	 */
	private void initRestaurants() throws IOException, URISyntaxException {
		listRestaurants = new LinkedList<Restaurant>();
		
		listRestaurants.add(new Restaurant(1, "Casa lvaro", "Avenida Comte de Llobregat, 113", "Martorell", new URI (BASE_URL + "/img/icons/resta1.jpg"), 9.5, 2,"63698723", "Si", "Espaa",""));
		
		listRestaurants.add(new Restaurant(2, "Vinya Nova", "Carrer Can marques,30", "Collbato", new URI (BASE_URL + "/img/icons/resta2.jpg"), 9, 3, "930983433","No", "Espaa",""));
		
		listRestaurants.add(new Restaurant(3, "Aqui T'espero", "Avenida Francesc Macia N 564", "Sabadell", new URI (BASE_URL + "/img/icons/resta3.jpg"), 10, 5, "908393038","Si", "Espaa",""));
		
		listRestaurants.add(new Restaurant(4, "Restaurant MUN cuina evocativa", " Rambleta Pare Alegre, 98", "Terrassa", 
				new URI (BASE_URL + "/img/icons/resta4.jpg"), 10, 5, "937333300","No", "Espaa","Ens agradaria fer l'alta en la vosta empresa."));
		
		listRestaurants.add(new Restaurant(5, "Pizza SI", " Placa del Vapor Ventallo, 2", "Terrassa", 
				new URI (BASE_URL + "/img/icons/resta5.jpg"), 10, 5, "","Si", "Espaa", "Som un restaurant itali i acceptem serveis a domicili. Ens doneu d'alta?"));
		
		listRestaurants.add(new Restaurant(6, "La Ginesa", "Carretera Matadepera, 161", "Terrassa", 
				new URI (BASE_URL + "/img/icons/resta6.jpg"), 10, 5, "7353002","No", "Espaa", "Som un restaurant de cuina mediterranea, ens accepteu?"));
	}

	/**
	 * Mapping entre Menus i Restaurantes
	 */
	private void initMapMenusRestaurants() {
		mapMenus = new HashMap<MenuPK, List<Menu>>();
		List<Menu> value = new LinkedList<Menu>();
		value.add(listMenu.get(0));
		mapMenus.put(new MenuPK(1, DateUtils.getFullDateAsString(new Date())), value );
		
		List<Menu> value2 = new LinkedList<Menu>();
		value2.add(listMenu.get(1));
		mapMenus.put(new MenuPK(2, DateUtils.getFullDateAsString(new Date())), value2 );	
		
		List<Menu> value3 = new LinkedList<Menu>();
		value3.add(listMenu.get(2));
		mapMenus.put(new MenuPK(3, DateUtils.getFullDateAsString(new Date())), value3 );
		
		List<Menu> value4 = new LinkedList<Menu>();
		value4.add(listMenu.get(3));
		mapMenus.put(new MenuPK(4, DateUtils.getFullDateAsString(new Date())), value4 );	
		
		List<Menu> value5 = new LinkedList<Menu>();
		value5.add(listMenu.get(4));
		mapMenus.put(new MenuPK(5, DateUtils.getFullDateAsString(new Date())), value5 );
		
		List<Menu> value6 = new LinkedList<Menu>();
		value6.add(listMenu.get(5));
		mapMenus.put(new MenuPK(6, DateUtils.getFullDateAsString(new Date())), value6 );
		
	}

	/**
	 * Mapping entre Usuaris i Empreses
	 */
	private void initMapUsersEmpreses() {
//		byte[] listAttachment =
//				IOUtils.toByteArray(PPOIOtaServiceTest.class.getResourceAsStream("/list/us_dunkindonuts.ov2"));
		mapEmpreses = new HashMap<String, List<Restaurant>>();
		List<Restaurant> value = new LinkedList<Restaurant>();
		value.add(listRestaurants.get(0));
		mapEmpreses.put("u", value);
		
		
	}
	
	/**
	 * Mapping entre Usuaris i Reserves
	 */
	private void initMapUsersReserves() {
		mapReserves = new HashMap<ReservaPK, Restaurant>();
		//mapReserves.put(new ReservaPK("u", date), value)
	}

	/**
	 * Mapping entre Usuaris y Restaurants
	 */
	private void initMapUsersRestaurants() {
		mapRestaurants = new HashMap<String, List<Restaurant>>();
		List<Restaurant> value = new LinkedList<Restaurant>();
		value.add(listRestaurants.get(0));
		value.add(listRestaurants.get(1));
		mapRestaurants.put("u", value);
	}

	public Map<String, List<Restaurant>> getMapRestaurants() {
		return mapRestaurants;
	}

	public Map<String, List<Restaurant>> getMapEmpreses() {
		return mapEmpreses;
	}

	public Map<MenuPK, List<Menu>> getMapMenus() {
		return mapMenus;
	}

	public Map<ReservaPK, Restaurant> getMapReserves() {
		return mapReserves;
	}


	public List<Restaurant> getListRestaurants() {
		return listRestaurants;
	}

	public List<Menu> getListMenu() {
		return listMenu;
	}

	public List<Menu> getMenusDelDia(String user, String day) {
		List<Menu> result = new ArrayList<Menu>();
		List<Restaurant> restaurants = mapRestaurants.get(user);
		if (restaurants != null) {
			for (Restaurant r : restaurants) {
				List<Menu> tmp = mapMenus.get(new MenuPK(r.getId(), day));
				if (tmp!=null) {
					result.addAll(tmp);
				}
			}
		}
		return result;
	}

	public Map<String, List<Restaurant>> getMapSolicitudsPendents() {
		return mapSolicitudsPendents;
	}

}
