package com.menutoday.dao.impl;

import java.lang.reflect.ParameterizedType;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.menutoday.dao.GenericJpaDao;

/**
 * 
 * @author igomezuoc
 *
 * @param <T>
 */
public class GenericJpaDaoImpl<T> implements GenericJpaDao<T> {

	@PersistenceContext(name = "menuapp")
	protected EntityManager em;

	private Class<T> clazz = null;

	public GenericJpaDaoImpl() {
		super();
	}

	@Override
	@Transactional(propagation = Propagation.REQUIRED)
	public void create(T entity) {
		this.em.persist(entity);
	}

	@Override
	@Transactional(propagation = Propagation.REQUIRED)
	public void delete(T entity) {
		this.em.remove(entity);
	}

	@Override
	@Transactional(propagation = Propagation.REQUIRED)
	public void update(T entity) {
		this.em.merge(entity);
	}

	@Override
	@Transactional(propagation = Propagation.REQUIRED)
	public T findByPrimaryKey(Object pk) {
		return this.em.find(this.getEntityClass(), pk);
	}

	private Class<T> getEntityClass() {
		if (this.clazz == null) {
			ParameterizedType genericSuperclass = (ParameterizedType) this.getClass().getGenericSuperclass();
			this.clazz = (Class<T>) genericSuperclass.getActualTypeArguments()[0];
		}
		return this.clazz;
	}
}
