package com.menutoday.service.impl;

import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.menutoday.dao.UserDAO;
import com.menutoday.dao.bo.Menu;
import com.menutoday.dao.bo.MockMenuAppData;
import com.menutoday.dao.bo.Restaurant;
import com.menutoday.dao.bo.pk.MenuPK;
import com.menutoday.dao.bo.pk.ReservaPK;
import com.menutoday.dao.model.User;
import com.menutoday.service.MenuTodayService;
import com.menutoday.utils.PerfilType;

@Service("mockMenuTodayService")
public class MockMenuTodayServiceImpl implements MenuTodayService {

	@Autowired
	private UserDAO userDao;
	
	@Autowired
	private MockMenuAppData mockData;
	
	@Override
	@Transactional(propagation = Propagation.REQUIRED)
	public PerfilType getPerfil(String name) {
		List<User> list = this.userDao.loadUserById(name);
		if (list != null && list.size() > 0) {
			return PerfilType.fromString(list.get(0).getPerfil());
		}
		return null;
	}

	@Override
	public List<Restaurant> getRestaurantsByUser(String user, String sorted) {
		List<Restaurant> restaurants = this.mockData.getMapRestaurants().get(user);
		if ("valoracio".equalsIgnoreCase(sorted)) {
			Collections.sort(restaurants, Restaurant.Comparators.VALORACIO);
		} else if ("preu".equalsIgnoreCase(sorted)) {
			Collections.sort(restaurants, Restaurant.Comparators.PREU);
		} else if ("proximitat".equalsIgnoreCase(sorted)) {
			// dyanic field do later
		} else {
			Collections.sort(restaurants, Restaurant.Comparators.NAME);
		}
		return restaurants;
	}

	@Override
	public List<Menu> getMenusByUser(String user, String day) throws URISyntaxException {
		return this.mockData.getMenusDelDia (user, day);
	}

	@Override
	public Restaurant isReservaInDay(String user, String day) {
		return this.mockData.getMapReserves().get(new ReservaPK(user, day));
	}

	@Override
	public void addReserva(String user, String day, int restaurant) {
		this.mockData.getMapReserves().put(new ReservaPK(user, day), this.mockData.getListRestaurants().get(restaurant-1));
	}

	@Override
	public void removeReserva(String user, String day) {
		this.mockData.getMapReserves().remove(new ReservaPK(user, day));		
	}

	@Override
	public Restaurant getRestaurantsById(int id) {
		return this.mockData.getListRestaurants().get(id-1);
	}

	@Override
	public List<Menu> getMenusById(int id, String day) {
		return this.mockData.getMapMenus().get(new MenuPK(id, day));
	}

	@Override
	@Transactional(propagation = Propagation.REQUIRED)
	public List<Restaurant> getSolicituds(String user, String status) {
		List<User> list = this.userDao.loadUserById(user);
		if (list.size() > 0) {
			if (this.mockData.getMapSolicitudsPendents().get(list.get(0).getEmpresa()) != null) {
				return this.mockData.getMapSolicitudsPendents().get(list.get(0).getEmpresa());
			} 
		}
		
		List<Restaurant> emptyResult = new ArrayList<Restaurant>();
		return emptyResult;
	}

	@Override
	@Transactional(propagation = Propagation.REQUIRED)
	public void approveSolicituds(String user, String ids) {
		String company = null;
		List<User> list = this.userDao.loadUserById(user);
		if (list.size() > 0) {
			company = list.get (0).getEmpresa();
		}
		if (company != null && ids.length() > 0) {
			List<User> listUsers = userDao.getAllUsers();
			for (User u : listUsers) {
				if (company.equals(u.getEmpresa()) && !PerfilType.
							isRoleRestaurant(
									PerfilType.fromString(u.getPerfil()))) {
					List<Restaurant> restaurants = new LinkedList<Restaurant>();
					StringTokenizer st = new StringTokenizer(ids, ",");
					while (st.hasMoreTokens()) {
						String id = st.nextToken();
						restaurants.add(this.mockData.getListRestaurants().get( (Integer.valueOf(id)) -1 ));
					}
					if (this.mockData.getMapRestaurants().get(u.getUsername()) != null) {
						this.mockData.getMapRestaurants().get(u.getUsername()).addAll(restaurants);
					} else {
						this.mockData.getMapRestaurants().put(u.getUsername(), restaurants);
					}
				}
			}
			this.mockData.getMapSolicitudsPendents().remove(company);
		}
	}
}
