package com.menutoday.utils;

import java.util.ArrayList;
import java.util.List;

import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;

import com.menutoday.dao.model.Perfil;

/**
 * 
 * @author igomezuoc
 *
 */
public final class LoginUtils {

	private LoginUtils() {
		super();
	}
	
	/**
	 * Find the user logged into spring-security according to SecurityContextHolder
	 * 
	 * @return
	 */
	public static boolean isAnonymousUser() {
		Object principal = SecurityContextHolder.getContext().getAuthentication().getPrincipal();
		String username = "";
		if (principal instanceof UserDetails) {
			username = ((UserDetails) principal).getUsername();
		} else {
			username = principal.toString();
		}

		return "anonymousUser".equals(username);
	}
	
	@SuppressWarnings("unchecked")
	public static boolean isRoleRestaurant () {
		Object principal = SecurityContextHolder.getContext().getAuthentication().getPrincipal();
		if (principal instanceof UserDetails) {
			UserDetails userDetails = (UserDetails) principal;
			List<Perfil> list = (ArrayList<Perfil>) userDetails.getAuthorities();
			if (list.size() > 0) {
				return  PerfilType.isRoleRestaurant(
							PerfilType.fromString(list.get(0).getNombrePerfil())
						);
			}
		}
		return false;
	}
	
	@SuppressWarnings("unchecked")
	public static boolean isRoleAdministrador () {
		Object principal = SecurityContextHolder.getContext().getAuthentication().getPrincipal();
		if (principal instanceof UserDetails) {
			UserDetails userDetails = (UserDetails) principal;
			List<Perfil> list = (ArrayList<Perfil>) userDetails.getAuthorities();
			if (list.size() > 0) {
				return  PerfilType.isRoleAdmin(
							PerfilType.fromString(list.get(0).getNombrePerfil())
						);
			}
		}
		return false;
	}

	public static String getUserName () {
		Object principal = SecurityContextHolder.getContext().getAuthentication().getPrincipal();
		if (principal instanceof UserDetails) {
			return ((UserDetails) principal).getUsername();
		}
		return "";
	}

}
